@@ -140,14 +140,6 @@ menushell_build_children (GladeXML *xml, GtkWidget *w,
 	{ GNOME_APP_UI_ITEM },
 	GNOMEUIINFO_END
     };
-#if 0
-    GtkAccelGroup *uline = NULL;
-    
-    if (strcmp (info->classname, "GtkMenuBar") != 0) {
-	uline = gtk_menu_ensure_uline_accel_group (GTK_MENU (w));
-	glade_xml_push_uline_accel (xml, uline);
-    }
-#endif
 
     for (i = 0; i < info->n_children; i++) {
 	GladeChildInfo *cinfo = &info->children[i];
@@ -324,8 +316,10 @@ dialog_build_children(GladeXML *self, GtkWidget *w,
 
     for (list = children; list; list = list->next) {
 	g_object_get (G_OBJECT (list->data), "label", &label, NULL);
-	if (label)
+	if (label) {
 	    gnome_dialog_append_button (dialog, label);
+	    g_free (label);
+	}
     }
 
     g_list_foreach (children, (GFunc)gtk_widget_unref, NULL);
@@ -375,7 +369,7 @@ app_build (GladeXML *xml, GType widget_type,
 	   GladeWidgetInfo *info)
 {
     GtkWidget *app;
-    const char *s;
+    char *s;
 
     app = glade_standard_build_widget (xml, widget_type, info);
 
@@ -385,6 +379,8 @@ app_build (GladeXML *xml, GType widget_type,
 
     g_object_set (G_OBJECT (app), "app_id", s, NULL);
 
+    g_free (s);
+
     return app;
 }
 
@@ -700,9 +696,7 @@ static void
 icon_entry_set_max_saved (GladeXML *xml, GtkWidget *w,
 			  const char *name, const char *value)
 {
-    entry_set_max_saved (xml,
-			 gnome_icon_entry_gnome_entry (GNOME_ICON_ENTRY (w)),
-			 name, value);
+    gnome_icon_entry_set_max_saved (GNOME_ICON_ENTRY (w), INT (value));
 }
 
 static void
@@ -772,6 +766,41 @@ about_set_authors (GladeXML *xml, GtkWidget *w,
     g_strfreev (authors);
 }
 
+static void
+about_set_translator_credits (GladeXML *xml, GtkWidget *w,
+			      const char *name, const char *value)
+{
+    /* only set this if the translator actually translated the string. */
+    if (strcmp(value, "translator_credits") != 0) {
+	g_object_set (G_OBJECT (w), "translator_credits", value, NULL);
+    }
+}
+
+static void
+about_set_documentors (GladeXML *xml, GtkWidget *w,
+		       const char *name, const char *value)
+{
+    char **documentors;
+    GValueArray *documentors_array;
+    int i;
+
+    documentors = g_strsplit (value, "\n", 0);
+    documentors_array = g_value_array_new (0);
+	
+    for (i = 0; documentors[i] != NULL; i++) {
+	GValue value = { 0 };
+		g_value_init (&value, G_TYPE_STRING);
+	g_value_set_static_string (&value, documentors[i]);
+	documentors_array = g_value_array_append (documentors_array, &value);
+    }
+
+    g_object_set (G_OBJECT (w), "documentors", documentors_array, NULL);
+
+    g_value_array_free (documentors_array);
+
+    g_strfreev (documentors);
+}
+
 static void
 pixmap_set_filename (GladeXML *xml, GtkWidget *w,
 		     const char *name, const char *value)
@@ -805,6 +834,8 @@ glade_module_register_widgets (void)
     glade_register_custom_prop (GNOME_TYPE_MESSAGE_BOX, "message", custom_noop);
     glade_register_custom_prop (GNOME_TYPE_MESSAGE_BOX, "message_box_type", custom_noop);
     glade_register_custom_prop (GNOME_TYPE_ABOUT, "authors", about_set_authors);
+    glade_register_custom_prop (GNOME_TYPE_ABOUT, "translator_credirs", about_set_translator_credits);
+    glade_register_custom_prop (GNOME_TYPE_ABOUT, "documentors", about_set_documentors);
     glade_register_custom_prop (GNOME_TYPE_DRUID_PAGE_EDGE, "title", custom_noop);
     glade_register_custom_prop (GNOME_TYPE_DRUID_PAGE_EDGE, "text", custom_noop);
     glade_register_custom_prop (GNOME_TYPE_DRUID_PAGE_EDGE, "title_color", custom_noop);
